/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<forecastcontrol.h>)
#  include <forecastcontrol.h>
#endif
#if __has_include(<locationscontrol.h>)
#  include <locationscontrol.h>
#endif
#if __has_include(<types.h>)
#  include <types.h>
#endif
#if __has_include(<util.h>)
#  include <util.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_plasma_applet_org_kde_plasma_weather()
{
    qmlRegisterModule("plasma.applet.org.kde.plasma.weather", 254, 0);
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    qmlRegisterTypesAndRevisions<ForecastControl>("plasma.applet.org.kde.plasma.weather", 254);
    qmlRegisterEnum<ForecastControl::Status>("ForecastControl::Status");
    qmlRegisterTypesAndRevisions<LocationsControl>("plasma.applet.org.kde.plasma.weather", 254);
    qmlRegisterTypesAndRevisions<PressureUnitListModel>("plasma.applet.org.kde.plasma.weather", 254);
    QMetaType::fromType<QAbstractItemModel *>().id();
    qmlRegisterEnum<QAbstractItemModel::LayoutChangeHint>("QAbstractItemModel::LayoutChangeHint");
    qmlRegisterEnum<QAbstractItemModel::CheckIndexOption>("QAbstractItemModel::CheckIndexOption");
    QMetaType::fromType<QAbstractListModel *>().id();
    QMetaType::fromType<QConcatenateTablesProxyModel *>().id();
    qmlRegisterTypesAndRevisions<TemperatureUnitListModel>("plasma.applet.org.kde.plasma.weather", 254);
    qmlRegisterTypesAndRevisions<Util>("plasma.applet.org.kde.plasma.weather", 254);
    qmlRegisterTypesAndRevisions<VisibilityUnitListModel>("plasma.applet.org.kde.plasma.weather", 254);
    qmlRegisterTypesAndRevisions<WarningsForeign>("plasma.applet.org.kde.plasma.weather", 254);
    qmlRegisterEnum<Warnings::WarningModel>("Warnings::WarningModel");
    qmlRegisterEnum<Warnings::PriorityClass>("Warnings::PriorityClass");
    qmlRegisterTypesAndRevisions<WindSpeedUnitListModel>("plasma.applet.org.kde.plasma.weather", 254);
    QT_WARNING_POP
    qmlRegisterModule("plasma.applet.org.kde.plasma.weather", 254, 254);
}

static const QQmlModuleRegistration plasmaappletorgkdeplasmaweatherRegistration("plasma.applet.org.kde.plasma.weather", qml_register_types_plasma_applet_org_kde_plasma_weather);
