/****************************************************************************
** Meta object code from reading C++ file 'documenthandler.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kdeplasma-addons-6.7.2/applets/notes/documenthandler.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'documenthandler.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15DocumentHandlerE_t {};
} // unnamed namespace

template <> constexpr inline auto DocumentHandler::qt_create_metaobjectdata<qt_meta_tag_ZN15DocumentHandlerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DocumentHandler",
        "QML.Element",
        "auto",
        "targetChanged",
        "",
        "cursorPositionChanged",
        "selectionStartChanged",
        "selectionEndChanged",
        "fontFamilyChanged",
        "textColorChanged",
        "alignmentChanged",
        "boldChanged",
        "italicChanged",
        "underlineChanged",
        "strikeOutChanged",
        "fontSizeChanged",
        "defaultFontSizeChanged",
        "defaultFontSizesChanged",
        "fileUrlChanged",
        "textChanged",
        "documentTitleChanged",
        "setBold",
        "arg",
        "setItalic",
        "setUnderline",
        "setStrikeOut",
        "setFontSize",
        "setDefaultFontSize",
        "setTextColor",
        "QColor",
        "setFontFamily",
        "setText",
        "setDocumentTitle",
        "pasteWithoutFormatting",
        "reset",
        "strip",
        "text",
        "stripAndSimplify",
        "strippedClipboardText",
        "target",
        "QQuickItem*",
        "cursorPosition",
        "selectionStart",
        "selectionEnd",
        "textColor",
        "fontFamily",
        "alignment",
        "Qt::Alignment",
        "bold",
        "italic",
        "underline",
        "strikeOut",
        "fontSize",
        "defaultFontSize",
        "defaultFontSizes",
        "documentTitle"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'targetChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'cursorPositionChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'selectionStartChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'selectionEndChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fontFamilyChanged'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'textColorChanged'
        QtMocHelpers::SignalData<void()>(9, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'alignmentChanged'
        QtMocHelpers::SignalData<void()>(10, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'boldChanged'
        QtMocHelpers::SignalData<void()>(11, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'italicChanged'
        QtMocHelpers::SignalData<void()>(12, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'underlineChanged'
        QtMocHelpers::SignalData<void()>(13, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'strikeOutChanged'
        QtMocHelpers::SignalData<void()>(14, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fontSizeChanged'
        QtMocHelpers::SignalData<void()>(15, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'defaultFontSizeChanged'
        QtMocHelpers::SignalData<void()>(16, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'defaultFontSizesChanged'
        QtMocHelpers::SignalData<void()>(17, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fileUrlChanged'
        QtMocHelpers::SignalData<void()>(18, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'textChanged'
        QtMocHelpers::SignalData<void()>(19, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'documentTitleChanged'
        QtMocHelpers::SignalData<void()>(20, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setBold'
        QtMocHelpers::SlotData<void(bool)>(21, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 22 },
        }}),
        // Slot 'setItalic'
        QtMocHelpers::SlotData<void(bool)>(23, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 22 },
        }}),
        // Slot 'setUnderline'
        QtMocHelpers::SlotData<void(bool)>(24, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 22 },
        }}),
        // Slot 'setStrikeOut'
        QtMocHelpers::SlotData<void(bool)>(25, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 22 },
        }}),
        // Slot 'setFontSize'
        QtMocHelpers::SlotData<void(int)>(26, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 22 },
        }}),
        // Slot 'setDefaultFontSize'
        QtMocHelpers::SlotData<void(int)>(27, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 22 },
        }}),
        // Slot 'setTextColor'
        QtMocHelpers::SlotData<void(const QColor &)>(28, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 29, 22 },
        }}),
        // Slot 'setFontFamily'
        QtMocHelpers::SlotData<void(const QString &)>(30, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 22 },
        }}),
        // Slot 'setText'
        QtMocHelpers::SlotData<void(const QString &)>(31, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 22 },
        }}),
        // Slot 'setDocumentTitle'
        QtMocHelpers::SlotData<void(QString)>(32, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 22 },
        }}),
        // Slot 'pasteWithoutFormatting'
        QtMocHelpers::SlotData<void()>(33, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'reset'
        QtMocHelpers::SlotData<void()>(34, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'strip'
        QtMocHelpers::MethodData<QString(const QString)>(35, 4, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 36 },
        }}),
        // Method 'stripAndSimplify'
        QtMocHelpers::MethodData<QString(const QString)>(37, 4, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 36 },
        }}),
        // Method 'strippedClipboardText'
        QtMocHelpers::MethodData<QString()>(38, 4, QMC::AccessPublic, QMetaType::QString),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'target'
        QtMocHelpers::PropertyData<QQuickItem*>(39, 0x80000000 | 40, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'cursorPosition'
        QtMocHelpers::PropertyData<int>(41, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'selectionStart'
        QtMocHelpers::PropertyData<int>(42, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'selectionEnd'
        QtMocHelpers::PropertyData<int>(43, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'textColor'
        QtMocHelpers::PropertyData<QColor>(44, 0x80000000 | 29, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 5),
        // property 'fontFamily'
        QtMocHelpers::PropertyData<QString>(45, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'alignment'
        QtMocHelpers::PropertyData<Qt::Alignment>(46, 0x80000000 | 47, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 6),
        // property 'bold'
        QtMocHelpers::PropertyData<bool>(48, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'italic'
        QtMocHelpers::PropertyData<bool>(49, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'underline'
        QtMocHelpers::PropertyData<bool>(50, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
        // property 'strikeOut'
        QtMocHelpers::PropertyData<bool>(51, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 10),
        // property 'fontSize'
        QtMocHelpers::PropertyData<int>(52, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 11),
        // property 'defaultFontSize'
        QtMocHelpers::PropertyData<int>(53, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 12),
        // property 'defaultFontSizes'
        QtMocHelpers::PropertyData<QStringList>(54, QMetaType::QStringList, QMC::DefaultPropertyFlags, 13),
        // property 'text'
        QtMocHelpers::PropertyData<QString>(36, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 15),
        // property 'documentTitle'
        QtMocHelpers::PropertyData<QString>(55, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 16),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<DocumentHandler, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject DocumentHandler::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15DocumentHandlerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15DocumentHandlerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15DocumentHandlerE_t>.metaTypes,
    nullptr
} };

void DocumentHandler::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DocumentHandler *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->targetChanged(); break;
        case 1: _t->cursorPositionChanged(); break;
        case 2: _t->selectionStartChanged(); break;
        case 3: _t->selectionEndChanged(); break;
        case 4: _t->fontFamilyChanged(); break;
        case 5: _t->textColorChanged(); break;
        case 6: _t->alignmentChanged(); break;
        case 7: _t->boldChanged(); break;
        case 8: _t->italicChanged(); break;
        case 9: _t->underlineChanged(); break;
        case 10: _t->strikeOutChanged(); break;
        case 11: _t->fontSizeChanged(); break;
        case 12: _t->defaultFontSizeChanged(); break;
        case 13: _t->defaultFontSizesChanged(); break;
        case 14: _t->fileUrlChanged(); break;
        case 15: _t->textChanged(); break;
        case 16: _t->documentTitleChanged(); break;
        case 17: _t->setBold((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 18: _t->setItalic((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 19: _t->setUnderline((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 20: _t->setStrikeOut((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 21: _t->setFontSize((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 22: _t->setDefaultFontSize((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 23: _t->setTextColor((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 24: _t->setFontFamily((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 25: _t->setText((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 26: _t->setDocumentTitle((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 27: _t->pasteWithoutFormatting(); break;
        case 28: _t->reset(); break;
        case 29: { QString _r = _t->strip((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 30: { QString _r = _t->stripAndSimplify((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 31: { QString _r = _t->strippedClipboardText();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DocumentHandler::*)()>(_a, &DocumentHandler::targetChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DocumentHandler::*)()>(_a, &DocumentHandler::cursorPositionChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DocumentHandler::*)()>(_a, &DocumentHandler::selectionStartChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DocumentHandler::*)()>(_a, &DocumentHandler::selectionEndChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DocumentHandler::*)()>(_a, &DocumentHandler::fontFamilyChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DocumentHandler::*)()>(_a, &DocumentHandler::textColorChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (DocumentHandler::*)()>(_a, &DocumentHandler::alignmentChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (DocumentHandler::*)()>(_a, &DocumentHandler::boldChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (DocumentHandler::*)()>(_a, &DocumentHandler::italicChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (DocumentHandler::*)()>(_a, &DocumentHandler::underlineChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (DocumentHandler::*)()>(_a, &DocumentHandler::strikeOutChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (DocumentHandler::*)()>(_a, &DocumentHandler::fontSizeChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (DocumentHandler::*)()>(_a, &DocumentHandler::defaultFontSizeChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (DocumentHandler::*)()>(_a, &DocumentHandler::defaultFontSizesChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (DocumentHandler::*)()>(_a, &DocumentHandler::fileUrlChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (DocumentHandler::*)()>(_a, &DocumentHandler::textChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (DocumentHandler::*)()>(_a, &DocumentHandler::documentTitleChanged, 16))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQuickItem* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QQuickItem**>(_v) = _t->target(); break;
        case 1: *reinterpret_cast<int*>(_v) = _t->cursorPosition(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->selectionStart(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->selectionEnd(); break;
        case 4: *reinterpret_cast<QColor*>(_v) = _t->textColor(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->fontFamily(); break;
        case 6: *reinterpret_cast<Qt::Alignment*>(_v) = _t->alignment(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->bold(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->italic(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->underline(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->strikeOut(); break;
        case 11: *reinterpret_cast<int*>(_v) = _t->fontSize(); break;
        case 12: *reinterpret_cast<int*>(_v) = _t->defaultFontSize(); break;
        case 13: *reinterpret_cast<QStringList*>(_v) = _t->defaultFontSizes(); break;
        case 14: *reinterpret_cast<QString*>(_v) = _t->text(); break;
        case 15: *reinterpret_cast<QString*>(_v) = _t->documentTitle(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setTarget(*reinterpret_cast<QQuickItem**>(_v)); break;
        case 1: _t->setCursorPosition(*reinterpret_cast<int*>(_v)); break;
        case 2: _t->setSelectionStart(*reinterpret_cast<int*>(_v)); break;
        case 3: _t->setSelectionEnd(*reinterpret_cast<int*>(_v)); break;
        case 4: _t->setTextColor(*reinterpret_cast<QColor*>(_v)); break;
        case 5: _t->setFontFamily(*reinterpret_cast<QString*>(_v)); break;
        case 6: _t->setAlignment(*reinterpret_cast<Qt::Alignment*>(_v)); break;
        case 7: _t->setBold(*reinterpret_cast<bool*>(_v)); break;
        case 8: _t->setItalic(*reinterpret_cast<bool*>(_v)); break;
        case 9: _t->setUnderline(*reinterpret_cast<bool*>(_v)); break;
        case 10: _t->setStrikeOut(*reinterpret_cast<bool*>(_v)); break;
        case 11: _t->setFontSize(*reinterpret_cast<int*>(_v)); break;
        case 12: _t->setDefaultFontSize(*reinterpret_cast<int*>(_v)); break;
        case 14: _t->setText(*reinterpret_cast<QString*>(_v)); break;
        case 15: _t->setDocumentTitle(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *DocumentHandler::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DocumentHandler::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15DocumentHandlerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int DocumentHandler::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 32)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 32;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 32)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 32;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    return _id;
}

// SIGNAL 0
void DocumentHandler::targetChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void DocumentHandler::cursorPositionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void DocumentHandler::selectionStartChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void DocumentHandler::selectionEndChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void DocumentHandler::fontFamilyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void DocumentHandler::textColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void DocumentHandler::alignmentChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void DocumentHandler::boldChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void DocumentHandler::italicChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void DocumentHandler::underlineChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void DocumentHandler::strikeOutChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void DocumentHandler::fontSizeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void DocumentHandler::defaultFontSizeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void DocumentHandler::defaultFontSizesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void DocumentHandler::fileUrlChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void DocumentHandler::textChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}

// SIGNAL 16
void DocumentHandler::documentTitleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 16, nullptr);
}
QT_WARNING_POP
