/****************************************************************************
** Meta object code from reading C++ file 'calendarsystem.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kdeplasma-addons-6.7.2/plasmacalendarplugins/alternatecalendar/calendarsystem.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'calendarsystem.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14CalendarSystemE_t {};
} // unnamed namespace

template <> constexpr inline auto CalendarSystem::qt_create_metaobjectdata<qt_meta_tag_ZN14CalendarSystemE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CalendarSystem",
        "System",
        "Gregorian",
        "Julian",
        "Milankovic",
        "Chinese",
        "Indian",
        "Hebrew",
        "Jalali",
        "Islamic",
        "IslamicCivil",
        "IslamicUmalqura",
        "Vietnamese"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'System'
        QtMocHelpers::EnumData<System>(1, 1, QMC::EnumFlags{}).add({
            {    2, System::Gregorian },
            {    3, System::Julian },
            {    4, System::Milankovic },
            {    5, System::Chinese },
            {    6, System::Indian },
            {    7, System::Hebrew },
            {    8, System::Jalali },
            {    9, System::Islamic },
            {   10, System::IslamicCivil },
            {   11, System::IslamicUmalqura },
            {   12, System::Vietnamese },
        }),
    };
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN14CalendarSystemE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}

static constexpr auto qt_staticMetaObjectContent_ZN14CalendarSystemE =
    CalendarSystem::qt_create_metaobjectdata<qt_meta_tag_ZN14CalendarSystemE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN14CalendarSystemE =
    qt_staticMetaObjectContent_ZN14CalendarSystemE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN14CalendarSystemE =
    qt_staticMetaObjectContent_ZN14CalendarSystemE.relocatingData;

Q_CONSTINIT const QMetaObject CalendarSystem::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN14CalendarSystemE.stringdata,
    qt_staticMetaObjectStaticContent_ZN14CalendarSystemE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN14CalendarSystemE.metaTypes,
    nullptr
} };

QT_WARNING_POP
