/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.11.1
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // main.xml
  0x0,0x0,0x2,0x4,
  0x28,
  0xb5,0x2f,0xfd,0x60,0xe6,0x5,0xd5,0xf,0x0,0xc6,0x5b,0x54,0x1f,0x20,0x93,0x1e,
  0x6f,0xd8,0xdc,0x52,0x24,0xac,0xec,0x5b,0xf8,0x4,0x74,0x23,0x53,0x1,0x31,0xf3,
  0x1f,0x80,0x5e,0x8d,0x29,0x98,0x5e,0x85,0x40,0x2,0x16,0xf,0x4e,0x0,0x4c,0x0,
  0x49,0x0,0x6c,0x75,0xa4,0xca,0xaa,0x25,0xcd,0x8e,0x19,0x86,0xb8,0xa2,0x14,0x33,
  0x6f,0xca,0xd5,0x76,0xca,0x9e,0x70,0x93,0x63,0xe6,0x10,0x27,0x10,0x4c,0x2,0x57,
  0xf8,0xf,0x5b,0x7e,0x83,0xf5,0xdd,0x6c,0x5d,0xf0,0xec,0xc6,0xcb,0x30,0x28,0x15,
  0xe8,0x3d,0x0,0x5,0x55,0x87,0x88,0xf0,0x1a,0x96,0x4b,0x64,0xc0,0x68,0xcb,0x6a,
  0x51,0x76,0xd1,0x24,0x5,0x22,0x3,0xad,0xed,0x97,0x3b,0x6e,0x66,0x9f,0x3,0x15,
  0xfd,0xd1,0xaa,0x11,0x2f,0xb4,0xb3,0x45,0xfb,0xc5,0x8c,0x37,0x56,0x25,0x22,0xc9,
  0xc0,0xc0,0x34,0x9,0x6,0x9e,0xf6,0x4f,0xc1,0x41,0x10,0xba,0xbc,0x51,0xd2,0xf8,
  0xe,0xb1,0x5b,0x25,0x96,0x1c,0xc9,0xe3,0xf1,0x40,0x58,0xb0,0xff,0x9b,0xc8,0xe0,
  0xd4,0x61,0x97,0xc5,0x79,0xf,0xba,0xfc,0x71,0xbe,0x5b,0xdf,0x24,0x9,0x5e,0x84,
  0xe2,0x70,0x85,0xcb,0x7d,0xf5,0x53,0x96,0x90,0xc7,0x4e,0x3,0xf5,0xa2,0x90,0xcb,
  0xb2,0x3b,0xf5,0x62,0xb4,0xef,0x3b,0x67,0x71,0xb2,0x79,0x33,0xd8,0x8a,0xd3,0x42,
  0x48,0x4d,0x83,0xea,0xa7,0x16,0x2f,0x96,0x4f,0xdb,0x6e,0xef,0xa2,0x19,0x3b,0x97,
  0x9f,0x42,0xf8,0xa3,0xb4,0xda,0x76,0x9f,0x32,0x55,0x45,0x5f,0xb9,0xbc,0xf9,0xc8,
  0x18,0xab,0xd5,0x8b,0x41,0x15,0x8c,0x22,0x3,0x67,0x91,0x3a,0x9e,0x7d,0x55,0x2e,
  0x92,0xfe,0x91,0x68,0xd,0x50,0x85,0x5d,0x16,0x7,0x52,0xdb,0xf7,0x6c,0x4d,0x7b,
  0x77,0x24,0xb3,0x75,0x77,0x7e,0xff,0xa6,0x97,0xed,0x5b,0x76,0xa6,0x3d,0xdc,0xf9,
  0x52,0x24,0x6d,0x8c,0x76,0xdf,0xf6,0xcf,0x5a,0x2d,0x98,0x8c,0xa,0xf6,0x19,0xaf,
  0x59,0xab,0x46,0x56,0xc9,0x5b,0xd1,0x66,0x75,0x41,0x21,0x7c,0xb5,0x8f,0x97,0x6d,
  0xc6,0x16,0x4f,0xdd,0xdc,0xc8,0xd6,0x26,0x20,0x65,0x5d,0xad,0x7a,0x40,0x20,0x10,
  0x10,0x62,0xc,0x94,0xb7,0xd,0x8,0x2c,0xa0,0xeb,0xa1,0xf0,0x91,0xc6,0xa6,0x73,
  0x8c,0x6f,0x6,0x76,0xc8,0xe1,0xbc,0x5,0x51,0xda,0x6e,0x1c,0xa1,0xd5,0xce,0xc4,
  0x50,0x22,0x4a,0x3c,0x43,0xa4,0xf0,0x53,0xd4,0xf5,0x75,0x22,0x27,0x37,0x7,0xaa,
  0x68,0x4c,0x49,0x90,0x52,0x89,0x56,0x3d,0x50,0x9c,0x52,0x3b,0xf6,0x44,0x48,0xc5,
  0xe8,0x40,0xad,0x9e,0x15,0xa,0xba,0x1d,0x14,0xd3,0x62,0xd4,0x95,0xb4,0x55,0x45,
  0xa9,0xb5,0x7,0x42,0x29,0x59,0x4e,0x8,0x78,0xfa,0xb2,0x9,0xa1,0x17,0xc0,0xd9,
  0x19,0xcd,0xf7,0x98,0xcb,0xe1,0x65,0x4a,0x1b,0x80,0x2f,0x8c,0x39,0x8,0x85,0x84,
  0x72,0x5a,0xbb,0xa0,0x90,0x37,0xf9,0x2a,0xad,0xda,0xb4,0x6b,0x3f,0x2c,0xbb,0xc2,
  0x53,0xf,0x92,0x1,0x80,0x28,0xdc,0x29,0xc8,0xaf,0xf0,0xc5,0x58,0xda,0xb,0x6f,
  0x8f,0xee,0x3b,0xc0,0x1b,0x7b,0x2f,0xb,0x73,0x25,0x21,0x81,0x77,0x3b,0x40,0xd6,
  0x61,0xa8,0x51,
  
};

static const unsigned char qt_resource_name[] = {
  // qt
  0x0,0x2,
  0x0,0x0,0x7,0x84,
  0x0,0x71,
  0x0,0x74,
    // qml
  0x0,0x3,
  0x0,0x0,0x78,0x3c,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,
    // plasma
  0x0,0x6,
  0x7,0x72,0x8a,0x31,
  0x0,0x70,
  0x0,0x6c,0x0,0x61,0x0,0x73,0x0,0x6d,0x0,0x61,
    // applet
  0x0,0x6,
  0x6,0x87,0x72,0xc4,
  0x0,0x61,
  0x0,0x70,0x0,0x70,0x0,0x6c,0x0,0x65,0x0,0x74,
    // org
  0x0,0x3,
  0x0,0x0,0x76,0x87,
  0x0,0x6f,
  0x0,0x72,0x0,0x67,
    // kde
  0x0,0x3,
  0x0,0x0,0x71,0xa5,
  0x0,0x6b,
  0x0,0x64,0x0,0x65,
    // weather
  0x0,0x7,
  0xd,0xb8,0xae,0x22,
  0x0,0x77,
  0x0,0x65,0x0,0x61,0x0,0x74,0x0,0x68,0x0,0x65,0x0,0x72,
    // main.xml
  0x0,0x8,
  0x8,0x1,0x51,0x5c,
  0x0,0x6d,
  0x0,0x61,0x0,0x69,0x0,0x6e,0x0,0x2e,0x0,0x78,0x0,0x6d,0x0,0x6c,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x9f,0x19,0x84,0x1f,0x48,
  // :/qt
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x9f,0x19,0x84,0x1f,0x48,
  // :/qt/qml
  0x0,0x0,0x0,0xa,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x1,0x9f,0x19,0x84,0x1f,0x48,
  // :/qt/qml/plasma
  0x0,0x0,0x0,0x16,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x4,
0x0,0x0,0x1,0x9f,0x19,0x84,0x1f,0x48,
  // :/qt/qml/plasma/applet
  0x0,0x0,0x0,0x28,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x5,
0x0,0x0,0x1,0x9f,0x19,0x84,0x1f,0x48,
  // :/qt/qml/plasma/applet/org
  0x0,0x0,0x0,0x3a,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x6,
0x0,0x0,0x1,0x9f,0x19,0x84,0x1f,0x48,
  // :/qt/qml/plasma/applet/org/kde
  0x0,0x0,0x0,0x46,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x7,
0x0,0x0,0x1,0x9f,0x19,0x84,0x1f,0x48,
  // :/qt/qml/plasma/applet/org/kde/plasma
  0x0,0x0,0x0,0x16,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x8,
0x0,0x0,0x1,0x9f,0x19,0x84,0x1f,0x48,
  // :/qt/qml/plasma/applet/org/kde/plasma/weather
  0x0,0x0,0x0,0x52,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x9,
0x0,0x0,0x1,0x9f,0x19,0x84,0x1f,0x48,
  // :/qt/qml/plasma/applet/org/kde/plasma/weather/main.xml
  0x0,0x0,0x0,0x66,0x0,0x4,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x9f,0x19,0x84,0x1f,0x48,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#if defined(__ELF__) || defined(__APPLE__)
static inline unsigned char qResourceFeatureZstd()
{
    extern const unsigned char qt_resourceFeatureZstd;
    return qt_resourceFeatureZstd;
}
#else
unsigned char qResourceFeatureZstd();
#endif

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_org_kde_plasma_weather_raw_res_1)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_org_kde_plasma_weather_raw_res_1)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_org_kde_plasma_weather_raw_res_1)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_org_kde_plasma_weather_raw_res_1)()
{
    int version = 3;
    version += QT_RCC_PREPEND_NAMESPACE(qResourceFeatureZstd());
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_org_kde_plasma_weather_raw_res_1)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_org_kde_plasma_weather_raw_res_1)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif
